import { RepeatIcon } from '@chakra-ui/icons';
import { Box, Button, VStack } from '@chakra-ui/react';
import { FactoryAPI } from '@mswjs/data/lib/glossary';

import { RestHandler } from 'msw';
import * as React from 'react';
import { DataTable } from './data-table';

export type MSWDevToolsProps = {
  db?: FactoryAPI<any>;
  handlers?: RestHandler[];
};

export function DataDevTools({ db }: { db: FactoryAPI<any> }) {
  const [data, setData] = React.useState<
    Record<string, Array<Record<string, unknown>>>
  >({});

  const loadDbs = React.useCallback(() => {
    const result = Object.entries(db).reduce<any>((acc, [k, v]) => {
      acc[k] = v.getAll();
      return acc;
    }, {});

    setData(result);
  }, [db, setData]);

  React.useEffect(() => {
    loadDbs();
  }, [loadDbs]);

  return (
    <VStack spacing="12">
      <Box>
        <Button
          leftIcon={<RepeatIcon />}
          flex="1"
          type="button"
          onClick={() => loadDbs()}
        >
          Refresh Data
        </Button>
      </Box>
      {Object.entries(data).map(([k, v]) => (
        <DataTable key={k} name={k} data={v} />
      ))}
    </VStack>
  );
}
