import {
  Box,
  Button,
  Flex,
  Text,
  Heading,
  Table,
  Tbody,
  Td,
  Th,
  Thead,
  Tr,
  VStack,
} from '@chakra-ui/react';
import * as React from 'react';

export function DataTable({
  name,
  data,
}: {
  name: string;
  data: Array<Record<string, unknown>>;
}) {
  const [isOpen, setIsOpen] = React.useState(false);
  const onToggle = () => setIsOpen((v) => !v);
  const columns = Object.keys(data?.[0] || {});
  return (
    <VStack w="full" bg="gray.50" p="4">
      <Flex w="full" justifyContent="space-between" alignItems="center">
        <Heading size="sm" textTransform="capitalize" alignSelf="start">
          {name} ({data.length})
        </Heading>
        <Button onClick={onToggle}>{isOpen ? 'Hide' : 'Show'}</Button>
      </Flex>

      {isOpen && (
        <Box overflow="auto" width="100%">
          <Table minWidth="100%">
            <Thead bg="gray.200">
              <Tr>
                {columns.map((column) => (
                  <Th textTransform="initial" key={column}>
                    {column}
                  </Th>
                ))}
              </Tr>
            </Thead>
            <Tbody>
              {data.map((entry) => (
                <Tr key={JSON.stringify(entry)}>
                  {columns.map((column) => (
                    <Td key={column}>
                      <Text maxWidth="250px" noOfLines={1}>
                        {entry[column] as string}
                      </Text>
                    </Td>
                  ))}
                </Tr>
              ))}
            </Tbody>
          </Table>
        </Box>
      )}
    </VStack>
  );
}
