import { ChevronLeftIcon, ChevronRightIcon } from '@chakra-ui/icons';
import {
  Button,
  Drawer,
  DrawerBody,
  DrawerCloseButton,
  DrawerContent,
  DrawerHeader,
  DrawerOverlay,
  Tab,
  TabList,
  TabPanel,
  TabPanels,
  Tabs,
  IconButton,
  ChakraProvider,
} from '@chakra-ui/react';
import { FactoryAPI } from '@mswjs/data/lib/glossary';
import { RestHandler } from 'msw';
import * as React from 'react';
import { APIDevtools } from './api-devtools';
import { DataDevTools } from './data-devtools';

export type MSWDevToolsProps = {
  db?: FactoryAPI<any>;
  handlers?: RestHandler[];
};

export function MSWDevTools({ db, handlers }: MSWDevToolsProps) {
  const [isOpen, setIsOpen] = React.useState(false);
  const onOpen = () => setIsOpen(true);
  const onClose = () => setIsOpen(false);
  const [size, setSize] = React.useState('xl');

  return (
    <ChakraProvider>
      <div>
        <Button
          zIndex="999"
          position="fixed"
          bottom="10px"
          right="10px"
          colorScheme="blue"
          onClick={onOpen}
        >
          Dev Tools
        </Button>
        <Drawer size={size} placement="right" onClose={onClose} isOpen={isOpen}>
          <DrawerOverlay />
          <DrawerContent>
            <DrawerCloseButton />

            <DrawerHeader borderBottomWidth="1px">
              <IconButton
                onClick={() => setSize((v) => (v === 'xl' ? 'full' : 'xl'))}
                aria-label="resize-drawer"
                icon={
                  size === 'xl' ? <ChevronLeftIcon /> : <ChevronRightIcon />
                }
                mr="4"
              />
              Devtools
            </DrawerHeader>
            <DrawerBody>
              <Tabs>
                <TabList>
                  <Tab>API</Tab>
                  {db && <Tab>Data</Tab>}
                </TabList>
                <TabPanels>
                  <TabPanel>
                    <APIDevtools handlers={handlers} />
                  </TabPanel>
                  {db && (
                    <TabPanel>
                      <DataDevTools db={db} />
                    </TabPanel>
                  )}
                </TabPanels>
              </Tabs>
            </DrawerBody>
          </DrawerContent>
        </Drawer>
      </div>
    </ChakraProvider>
  );
}
